@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2021 ircd-hybrid development team
+ *  Copyright (c) 1997-2022 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,19 +21,17 @@
 
 /*! \file channel_mode.h
  * \brief Includes channel mode related definitions and structures.
- * \version $Id$
  */
 
 #ifndef INCLUDED_channel_mode_h
 #define INCLUDED_channel_mode_h
 
 
-#define CMEMBER_STATUS_FLAGS "@%+"
-enum { CMEMBER_STATUS_FLAGS_LEN = sizeof(CMEMBER_STATUS_FLAGS) - 1 };
+enum { CMEMBER_STATUS_FLAGS_LEN = 5 };
 
 enum { MODEBUFLEN = 200 };
 
-/* Maximum mode changes allowed per client, per server is different */
+/** Maximum mode changes allowed per client, per server is different */
 enum { MAXMODEPARAMS = 6 };
 
 enum
@@ -47,33 +45,63 @@ enum
 {
   CHACCESS_NOTONCHAN = -1,
   CHACCESS_PEON,
+  CHACCESS_VOICE,
   CHACCESS_HALFOP,
-  CHACCESS_CHANOP,
+  CHACCESS_OP,
+  CHACCESS_ADMIN,
+  CHACCESS_OWNER,
   CHACCESS_REMOTE
 };
 
-/* Channel related flags */
-enum
+enum mode_class
 {
-  CHFL_CHANOP       = 1 << 0,  /* Channel operator   */
-  CHFL_HALFOP       = 1 << 1,  /* Channel half op    */
-  CHFL_VOICE        = 1 << 2,  /* the power to speak */
-  CHFL_BAN          = 1 << 3,  /* ban channel flag */
-  CHFL_EXCEPTION    = 1 << 4,  /* exception to ban channel flag */
-  CHFL_INVEX        = 1 << 5,
-  /* Cache flags for silence on ban */
-  CHFL_BAN_CHECKED  = 1 << 6,
-  CHFL_BAN_SILENCED = 1 << 7,
-  CHFL_MUTE_CHECKED = 1 << 8
+  /* A = modes that take a parameter, and add or remove nicks
+   *     or addresses to a list, such as +bIe for the ban,
+   *     invite, and exception lists.
+   */
+  MODE_CLASS_A,
+
+  /* B = modes that change channel settings, but which take
+   *     a parameter when they are set and unset, such as
+   *     +k key, and -k key.
+   */
+  MODE_CLASS_B,
+
+  /* C = modes that change channel settings, but which take
+   *     a parameter only when they are set, such as +l N,
+   *     and -l.
+   */
+  MODE_CLASS_C,
+
+  /* D = modes that change channel settings, such as +imnpst
+   *     and take no parameters.
+   */
+  MODE_CLASS_D
 };
 
-/* channel modes ONLY */
+/** Channel related flags */
+enum
+{
+  CHFL_CHANOWNER    = 1 <<  0,  /**< Channel owner (~) */
+  CHFL_CHANADMIN    = 1 <<  1,  /**< Channel admin (&) */
+  CHFL_CHANOP       = 1 <<  2,  /**< Channel operator (@) */
+  CHFL_HALFOP       = 1 <<  3,  /**< Channel half-op (%) */
+  CHFL_VOICE        = 1 <<  4,  /**< Channel voice (+) */
+  CHFL_BAN          = 1 <<  5,  /* ban channel flag */
+  CHFL_EXCEPTION    = 1 <<  6,  /* exception to ban channel flag */
+  CHFL_INVEX        = 1 <<  7,
+  /* Cache flags for silence on ban */
+  CHFL_BAN_CHECKED  = 1 <<  8,
+  CHFL_BAN_SILENCED = 1 <<  9,
+};
+
+/** Channel mode flags */
 enum
 {
   MODE_PRIVATE      = 1 <<  0,  /**< */
   MODE_SECRET       = 1 <<  1,  /**< Channel does not show up on NAMES or LIST */
-  MODE_MODERATED    = 1 <<  2,  /**< Users without +v/+h/+o cannot send text to the channel */
-  MODE_TOPICLIMIT   = 1 <<  3,  /**< Only chanops can change the topic */
+  MODE_MODERATED    = 1 <<  2,  /**< Users without +v or higher cannot send text to the channel */
+  MODE_TOPICLIMIT   = 1 <<  3,  /**< Only chanops or higher can change the topic */
   MODE_INVITEONLY   = 1 <<  4,  /**< Only invited users may join this channel */
   MODE_NOPRIVMSGS   = 1 <<  5,  /**< Users must be in the channel to send text to it */
   MODE_SECUREONLY   = 1 <<  6,  /**< Prevents anyone who isn't connected via TLS from joining the channel */
@@ -84,10 +112,12 @@ enum
   MODE_MODREG       = 1 << 11,  /**< Unregistered/unidentified clients cannot send text to the channel */
   MODE_NOCTCP       = 1 << 12,  /**< Clients cannot send CTCP messages to the channel */
   MODE_NONOTICE     = 1 << 13,  /**< Clients cannot send NOTICE to the channel */
-  MODE_HIDEBMASKS   = 1 << 14,  /**< Hides +b/+e/+I lists/changes for non-chanops everywhere */
-  MODE_EXTLIMIT     = 1 << 15,  /**< Channel can make use of the extended ban list limit */
-  MODE_NONICKCHANGE = 1 << 16,  /**< User is prevented from changing their nick while in this channel */
-  MODE_NOKNOCK      = 1 << 17   /**< Clients may not use KNOCK on this channel */
+  MODE_EXTLIMIT     = 1 << 14,  /**< Channel can make use of the extended ban list limit */
+  MODE_NONICKCHANGE = 1 << 15,  /**< User is prevented from changing their nick while in this channel */
+  MODE_NOKNOCK      = 1 << 16,  /**< Clients may not use KNOCK on this channel */
+  MODE_NOKICK       = 1 << 17,  /**< Clients may not use KICK on this channel */
+  MODE_ISSECURE     = 1 << 18,
+  MODE_NOINVITE     = 1 << 19,  /**< Clients may not use INVITE on this channel */
 };
 
 #define HasCMode(x, y) ((x)->mode.mode &   (y))
@@ -95,10 +125,7 @@ enum
 #define DelCMode(x, y) ((x)->mode.mode &= ~(y))
 
 /* name invisible */
-#define SecretChannel(x)        (((x)->mode.mode & MODE_SECRET))
 #define PubChannel(x)           (((x)->mode.mode & (MODE_PRIVATE | MODE_SECRET)) == 0)
-/* knock is forbidden, halfops can't kick/deop other halfops. */
-#define PrivateChannel(x)       (((x)->mode.mode & MODE_PRIVATE))
 
 struct ChModeChange
 {
@@ -106,27 +133,32 @@ struct ChModeChange
   const char *arg;
   const char *id;
   unsigned int dir;
-  unsigned int flags;
 };
 
 struct chan_mode
 {
   unsigned char letter;
+  unsigned char prefix;
   unsigned int mode;
   unsigned int flag;
+  enum mode_class class;
   bool only_opers;
   bool only_servers;
-  int required_oplevel;
+  int required_rank;
+  int rank;
   void (*func)(struct Client *,
-               struct Channel *, int, int *, char **, int *,
+               struct Channel *, int, int *, char *[], int *,
                int, int, const char, const struct chan_mode *);
 };
 
 extern const struct chan_mode *cmode_map[];
 extern const struct chan_mode  cmode_tab[];
+extern const struct chan_mode  cflag_tab[];
+extern char cmode_rpl04[][256];
+extern char cmode_class[][256];
 
 extern void channel_mode_init(void);
 extern const char *add_id(struct Client *, struct Channel *, const char *, dlink_list *, unsigned int);
-extern void channel_mode_set(struct Client *, struct Channel *, struct ChannelMember *, int, char **);
+extern void channel_mode_set(struct Client *, struct Channel *, int, char *[]);
 extern void clear_ban_cache_list(dlink_list *);
 #endif  /* INCLUDED_channel_mode_h */
