@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2021 ircd-hybrid development team
+ *  Copyright (c) 1997-2022 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id$
  */
 
 
@@ -35,17 +34,15 @@
 #include "auth.h"
 
 
-/*
- * status macros.
- */
+/** Client connection states */
 enum
 {
-  STAT_CONNECTING = 1,
-  STAT_HANDSHAKE,
-  STAT_ME,
-  STAT_UNKNOWN,
-  STAT_SERVER,
-  STAT_CLIENT
+  STAT_CONNECTING = 1,  /**< Connecting to another server */
+  STAT_HANDSHAKE,  /**< PASS, CAPAB, and SERVER sent */
+  STAT_ME,  /**< This is &me */
+  STAT_UNKNOWN,  /**< Unknown/unidentified connection */
+  STAT_SERVER,  /**< Fully registered server */
+  STAT_CLIENT,  /**< Fully registered client */
 };
 
 enum
@@ -86,31 +83,24 @@ enum
 #define MyConnect(x)            ((x)->connection != NULL)
 #define MyClient(x)             (MyConnect(x) && IsClient(x))
 
-/*
- * ts stuff
- */
-enum
-{
-  TS_CURRENT = 6,  /**< Current TS protocol version */
-  TS_MINIMUM = 6,  /**< Minimum supported TS protocol version */
-};
 
+/** IRCv3 extension flags */
 enum
 {
-  CAP_MULTI_PREFIX   = 1 << 0,  /**< ircv3.1 multi-prefix client capability */
-  CAP_AWAY_NOTIFY    = 1 << 1,  /**< ircv3.1 away-notify client capability */
-  CAP_UHNAMES        = 1 << 2,  /**< ircv3.2 userhost-in-names client capability */
-  CAP_EXTENDED_JOIN  = 1 << 3,  /**< ircv3.1 extended-join client capability */
-  CAP_ACCOUNT_NOTIFY = 1 << 4,  /**< ircv3.1 account-notify client capability */
-  CAP_INVITE_NOTIFY  = 1 << 5,  /**< ircv3.2 invite-notify client capability */
-  CAP_CHGHOST        = 1 << 6,  /**< ircv3.2 chghost client capability */
-  CAP_CAP_NOTIFY     = 1 << 7,  /**< ircv3 CAP LS 302 cap-notify client capability */
+  CAP_MULTI_PREFIX   = 1 << 0,  /**< multi-prefix client capability */
+  CAP_AWAY_NOTIFY    = 1 << 1,  /**< away-notify client capability */
+  CAP_UHNAMES        = 1 << 2,  /**< userhost-in-names client capability */
+  CAP_EXTENDED_JOIN  = 1 << 3,  /**< extended-join client capability */
+  CAP_ACCOUNT_NOTIFY = 1 << 4,  /**< account-notify client capability */
+  CAP_INVITE_NOTIFY  = 1 << 5,  /**< invite-notify client capability */
+  CAP_CHGHOST        = 1 << 6,  /**< chghost client capability */
+  CAP_CAP_NOTIFY     = 1 << 7,  /**< CAP LS 302 cap-notify client capability */
 };
 
 #define HasCap(x, y) ((x)->connection->cap & (y))
 
 
-/* housekeeping flags */
+/** Client flags */
 enum
 {
   FLAGS_PINGSENT      = 1 <<  0,  /**< Unreplied ping sent */
@@ -145,7 +135,7 @@ enum
 #define DelFlag(x, y) ((x)->flags &= ~(y))
 
 
-/* umodes, settable flags */
+/** User mode flags */
 enum
 {
   UMODE_SERVNOTICE   = 1 <<  0,  /**< Server notices such as kill */
@@ -154,7 +144,7 @@ enum
   UMODE_SKILL        = 1 <<  3,  /**< Server Killed */
   UMODE_FLOOD        = 1 <<  4,  /**< Flooding/spambot notices */
   UMODE_SPY          = 1 <<  5,  /**< See STATS / LINKS */
-  UMODE_DEBUG        = 1 <<  6,  /**< 'debugging' info */
+/*UMODE_             = 1 <<  6,*/  /**<  */
   UMODE_NCHANGE      = 1 <<  7,  /**< Nick change notice */
   UMODE_WALLOP       = 1 <<  8,  /**< Send wallops to them */
   UMODE_INVISIBLE    = 1 <<  9,  /**< Makes user invisible */
@@ -174,7 +164,8 @@ enum
   UMODE_HIDEIDLE     = 1 << 23,  /**< Hides idle and signon time in WHOIS */
   UMODE_HIDECHANS    = 1 << 24,  /**< Hides channel list in WHOIS */
   UMODE_EXPIRATION   = 1 << 25,  /**< Receives *LINE expiration notices */
-  UMODE_BOT          = 1 << 26  /**< Client is marked as a bot in WHOIS and WHO */
+  UMODE_BOT          = 1 << 26,  /**< Client is marked as a bot in WHOIS and WHO */
+  UMODE_SECUREONLY   = 1 << 27,  /**< Client may only receive private messages from secure connections */
 };
 
 #define HasUMode(x, y) ((x)->umodes &   (y))
@@ -239,7 +230,7 @@ enum
 #define IsHidden(x)             ((x)->flags &  FLAGS_HIDDEN)
 
 
-/*! \brief server ban types */
+/** Server ban types */
 enum
 {
   CLIENT_BAN_KLINE,
@@ -247,7 +238,7 @@ enum
   CLIENT_BAN_XLINE
 };
 
-/*! \brief addr_mask_type enumeration */
+/** addr_mask_type enumeration */
 enum addr_mask_type
 {
   HIDE_IP,  /**< IP is hidden. Resolved hostname is shown instead */
@@ -255,7 +246,7 @@ enum addr_mask_type
   MASK_IP   /**< IP is masked. 255.255.255.255 is shown instead */
 };
 
-/*! \brief Server structure */
+/** Server structure */
 struct Server
 {
   dlink_list server_list;  /**< Servers on this server */
@@ -263,7 +254,7 @@ struct Server
   char by[NICKLEN + 1];  /**< Who activated this connection */
 };
 
-/*! \brief ListTask structure */
+/** ListTask structure */
 struct ListTask
 {
   dlink_node node;  /**< Embedded list node used to link into listing_client_list */
@@ -280,10 +271,9 @@ struct ListTask
   char topic[TOPICLEN + 1];
 };
 
-/*! \brief Connection structure
- *
+/** Connection structure
  * Allocated only for local clients, that are directly connected
- * to \b this server with a socket.
+ * to this server with a socket.
  */
 struct Connection
 {
@@ -296,7 +286,7 @@ struct Connection
   unsigned int operflags;  /**< IRC Operator privilege flags */
   unsigned int random_ping;  /**< Holding a 32bit value used for PING cookies */
 
-  uintmax_t serial;  /**< Used to enforce 1 send per nick */
+  uintmax_t send_marker;  /**< Used to enforce one send per user */
   uintmax_t last_data;  /**< Last time data read from socket; monotonic time */
   uintmax_t last_ping;  /**< Last time data read from socket; currently this is a copy of last_data
                              which can be modified by check_pings_list; monotonic time */
@@ -348,7 +338,7 @@ struct Connection
   char *password;  /**< Password supplied by the client/server */
 };
 
-/*! \brief Client structure */
+/** Client structure */
 struct Client
 {
   dlink_node node;
@@ -383,8 +373,7 @@ struct Client
   char id[IDLEN + 1];  /**< Client ID, unique ID per client */
   char account[ACCOUNTLEN + 1];  /**< Services account */
 
-  /*
-   * client->username is the username from ident or the USER message,
+  /** client->username is the username from ident or the USER message,
    * If the client is idented the USER message is ignored, otherwise
    * the username part of the USER message is put here prefixed with a
    * tilde depending on the auth{} block. Once a client has registered,
@@ -392,29 +381,25 @@ struct Client
    */
   char username[USERLEN + 1];  /**< client's username */
 
-  /*
-   * client->host contains the resolved name or ip address as a string
+  /** client->host contains the resolved name or ip address as a string
    * for the user, it may be fiddled with for oper spoofing etc.
    * once it's changed the *real* address goes away.
    */
   char host[HOSTLEN + 1];  /**< Client's hostname. Can be faked/spoofed */
 
-  /*
-   * client->realhost contains the resolved name or ip address as a string
+  /** client->realhost contains the resolved name or ip address as a string
    * for the user. Once a client has registered, this field should be
    * considered read-only.
    */
   char realhost[HOSTLEN + 1];  /**< Client's real hostname */
 
 
-  /*
-   * client->info for unix clients will normally contain the info from the
+  /** client->info for unix clients will normally contain the info from the
    * gcos field in /etc/passwd but anything can go here.
    */
   char info[REALLEN + 1];  /**< Free form additional client info */
 
-  /*
-   * client->sockhost contains the ip address gotten from the socket as a
+  /** client->sockhost contains the ip address gotten from the socket as a
    * string, this field should be considered read-only once the connection
    * has been made. (set in s_bsd.c only)
    */
