@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2021 ircd-hybrid development team
+ *  Copyright (c) 1997-2022 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 /*! \file conf.h
  * \brief A header for the configuration functions.
- * \version $Id: conf.h 9926 2021-04-16 14:42:12Z michael $
  */
 
 #ifndef INCLUDED_conf_h
@@ -213,6 +212,8 @@ struct config_general_entry
 struct config_channel_entry
 {
   unsigned int enable_extbans;
+  unsigned int enable_owner;
+  unsigned int enable_admin;
   unsigned int disable_fake_channels;
   unsigned int invite_client_count;
   unsigned int invite_client_time;
