@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2021 ircd-hybrid development team
+ *  Copyright (c) 1997-2022 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 /*! \file listener.h
  * \brief A header for the listener code.
- * \version $Id: listener.h 10007 2021-07-22 15:28:05Z michael $
  */
 
 #ifndef INCLUDED_listener_h
@@ -29,24 +28,26 @@
 
 #include "fdlist.h"
 
+/** Listener flags */
 enum
 {
-  LISTENER_TLS    = 1 << 0,
-  LISTENER_HIDDEN = 1 << 1,
-  LISTENER_SERVER = 1 << 2,
-  LISTENER_CLIENT = 1 << 3,
-  LISTENER_DEFER  = 1 << 4
+  LISTENER_TLS    = 1 << 0,  /**< Listener accepts only TLS connections */
+  LISTENER_HIDDEN = 1 << 1,  /**< Listener doesn't show up in '/stats P', except for server administrators */
+  LISTENER_SERVER = 1 << 2,  /**< Listener accepts only server connections */
+  LISTENER_CLIENT = 1 << 3,  /**< Listener accepts only client connections */
+  LISTENER_DEFER  = 1 << 4,  /**< Listener has the TCP_DEFER_ACCEPT/SO_ACCEPTFILTER socket option enabled */
 };
 
+/** Entry for a single listener/port */
 struct Listener
 {
-  dlink_node node;  /**< Doubly linked list node */
+  dlink_node node;  /**< List node; linked into listener_list */
   bool active;  /**< Current state of listener */
   fde_t *fd;  /**< File descriptor */
   int port;  /**< Listener IP port */
   int ref_count;  /**< Number of connection references */
   struct irc_ssaddr addr;  /**< Holds an IPv6 or IPv4 address */
-  char *name;  /**< Holds an IPv6 or IPv4 address in string representation*/
+  char *name;  /**< Holds an IPv6 or IPv4 address in string representation */
   unsigned int flags;  /**< Listener flags (tls, hidden, server, client, defer) */
 };
 
